# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

## [Unreleased]

Compatible with icevision 0.10

### Changed
- Added `gdrive` parameter to `load_data`
- Bug fixes

### Deleted

## [0.2.0]
- Compatible with icevision 0.5
### Added
- `OCHuman` dataset
- `BIWI` dataset

## [0.1.0]

### IMPORTANT
- **Switched from poetry to setuptools**

## Added
- Dataset template

## [0.0.3]

## Fixes
- `load_data` caching

## [0.0.2]

## Added
- Added `trained_models` module
- `NUM_CLASSES` constant to datasets

## Changed
- Renamed `load` to `load_data`

## Deleted